<?php
/**
 * \Genealogy\Gedcom\Note
 *
 * PHP version 5
 *
 * @category  File_Formats
 * @package   Genealogy_Gedcom_Structures
 * @author    Ed Thompson <ed4becky@gmail.com>
 * @copyright 2010 Ed Thompson
 * @license   http://www.opensource.org/licenses/Apache2.0.php Apache License
 * @version   SVN: $Id: Note.php 291 2010-03-30 19:38:34Z ed4becky $
 * @link
 */

/**
 * Citation class RP_for Genealogy_Gedcom
 *
 * @category  File_Formats
 * @package   Genealogy_Gedcom_Structures
 * @author    Ed Thompson <ed4becky@gmail.com>
 * @copyright 2010 Ed Thompson
 * @license   http://www.opensource.org/licenses/Apache2.0.php Apache License
 * @link
 */
class RP_Note extends RP_Entity_Abstract
{
    var $id;
    var $text;

    /**
     * Flattens the object into a GEDCOM compliant format
     *
     * This method guarantees compliance, not re-creation of
     * the original order of the records.
     *
     * @param int $lvl indicates the level at which this record
     *                    should be generated
     * @param string $ver represents the version of the GEDCOM standard
     *
     * @return string a return character delimited string of gedcom records
     *
     * @access public
     * @since Method available since Release 0.0.1
     */
    public function to_gedcom($lvl, $ver)
    {
        if (!isset($ver)
            || $ver === ''
        ) {
            $ver = $this->ver;
        }
        $ged_rec = '';
        if (strpos($ver, '5.5.1') == 0) {
            if (isset($this->id)
                && $this->id != ''
            ) {
                $ged_rec .= $lvl . ' ' . Rp_Tags::NOTE . ' @' . $this->id . '@';
            } else if (isset($this->text)
                && $this->text != ''
            ) {
                $ged_rec .= parent::to_con_tag($this->text, Rp_Tags::NOTE, $lvl);
            }
        }
        return $ged_rec;
    }

    /**
     * Extracts attribute contents FROM a parent tree object
     *
     * @param array $tree an array containing an array FROM which the
     *                     object data should be extracted
     * @param string $ver represents the version of the GEDCOM standard
     *                     data is being extracted from
     *
     *
     * @access public
     * @since Method available since Release 0.0.1
     */
    public function parse_tree($tree, $ver)
    {
        $this->ver = $ver;
        if (($i1 = parent::find_tag($tree, Rp_Tags::NOTE)) !== false) {
            $str = parent::parse_ptr_id($tree[$i1], Rp_Tags::NOTE);
            if (isset($str) && $str != '') {
                $this->id = $str;
            } else {
                $this->text = parent::parse_con_tag($tree[$i1], Rp_Tags::NOTE);
            }
        }
    }

    /**
     * Creates a string representation of the object
     *
     * @return string  contains string representation of each
     *                 public field in the object
     *
     * @access public
     * @since Method available since Release 0.0.1
     */
    public function __toString()
    {
        $str = __CLASS__ . '(Version->' . $this->ver . ((isset($this->id)
                && $this->id != '') ? (', Id->' . $this->id) : (', Text->' . $this->text)) . ')';
        return $str;
    }
}
